@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-#$Id: iso3.pl,v 1.3 2006/03/03 21:11:09 rocky Exp $
+#$Id: iso3.pl,v 1.4 2006/03/31 02:29:34 rocky Exp $
 #
 #  Copyright (C) 2006 Rocky Bernstein <rocky@cpan.org>
 #  
@@ -65,7 +65,8 @@ Extracts filename from ISO9660-image.ISO.
 my $iso = Device::Cdio::ISO9660::IFS->new(-source=>$iso_image_fname);
   
 if (!defined($iso)) {
-    printf "Sorry, couldn't open %s as an ISO-9660 image\n", $iso_image_fname;
+    printf "Sorry, couldn't open %s as an ISO-9660 image\n.", 
+    $iso_image_fname;
     exit 1;
 }
 
